@@ -3,13 +3,13 @@
  *
  * This file is a part of the Sophos Anti-Virus Interface (SAVI)(tm).
  *
- * Copyright (C) 1997,2000 Sophos Plc, Oxford, England.
+ * Copyright (C) 2002 Sophos Plc, Oxford, England.
  * All rights reserved.
  *
  * This source code is only intended as a supplement to the
  * SAVI(tm) Reference and related documentation for the library.
  *
- * Cross platform type definitions
+ * Cross platform type definitions.
  */
 
 #ifndef __SAVICHAR_DOT_H__
@@ -22,13 +22,16 @@
 #  ifndef __SOPHOS_TCHAR_DEFINED__
 #     define __SOPHOS_TCHAR_DEFINED__
 #  endif /* __SOPHOS_TCHAR_DEFINED__ */
+
+#  define SOPHOS_COMSTR(str) L ## str
+
 #else  /* __SOPHOS_WIN32__ */
 
 #  ifndef __SOPHOS_TCHAR_DEFINED__
 #    define __SOPHOS_TCHAR_DEFINED__
 
 #    if  defined(__SOPHOS_OS2__)
-#      include <tchar.h>
+#       include <tchar.h>
 #    else
         typedef char TCHAR;
 #       define _tprintf printf
@@ -46,6 +49,8 @@
    typedef const char * LPCOLESTR;
 #  define OLESTR(str) str
 
+#  define SOPHOS_COMSTR(str) str
+
 #endif /* __SOPHOS_WIN32__ */
 
 #endif /* __SAVICHAR_DOT_H__ */
